@@ -252,6 +252,10 @@ class TestBaseEnum(TestField):
         field2 = FakeEnumAltField()
         self.assertNotEqual(str(field1), str(field2))
 
+    def test_valid_values(self):
+        self.assertEqual(self.field.valid_values,
+                         FakeEnum.ALL)
+
 
 class TestEnum(TestField):
     def setUp(self):
@@ -313,15 +317,20 @@ class TestStateMachine(TestField):
                 'status': FakeStateMachineField(),
             }
 
-        obj = AnObject()
+        obj = AnObject(status='ERROR')
 
-        with testtools.ExpectedException(
-                ValueError,
-                msg="AnObject's are not allowed transition out "
-                "of 'ERROR' state to 'PENDING' state, choose from "
-                "['PENDING']"):
-            obj.status = FakeStateMachineField.ERROR
+        try:
             obj.status = FakeStateMachineField.ACTIVE
+        except ValueError as e:
+            ex = e
+        else:
+            ex = None
+
+        self.assertIsNotNone(ex, 'Invalid transition failed to raise error')
+        self.assertEqual('AnObject.status is not allowed to transition out '
+                         'of \'ERROR\' state to \'ACTIVE\' state, choose from '
+                         '[\'PENDING\']',
+                         str(ex))
 
     def test_bad_initial_value(self):
         @obj_base.VersionedObjectRegistry.register
@@ -810,6 +819,13 @@ class TestObject(TestField):
         self.assertRaises(ValueError, pigs.coerce, None, "animal", wolfy)
         self.assertEqual(babe, pigs.coerce(None, "animal", babe))
 
+    def test_coerce_bad_value_primitive_type(self):
+        # Tests that the ValueError has the primitive type in it's message.
+        ex = self.assertRaises(ValueError, self.field.coerce,
+                               'obj', 'attr', [{}])
+        self.assertEqual('An object of type TestableObject is required '
+                         'in field attr, not a list', six.text_type(ex))
+
 
 class TestIPAddress(TestField):
     def setUp(self):
