@@ -22,6 +22,7 @@ import mock
 import six
 
 from oslo_versionedobjects import base
+from oslo_versionedobjects import exception
 from oslo_versionedobjects import fields
 from oslo_versionedobjects import fixture
 from oslo_versionedobjects import test
@@ -140,6 +141,15 @@ class TestObjectComparators(test.TestCase):
                                                       replaced_dt)
 
 
+class FakeResource(base.VersionedObject):
+    # Version 1.0: Initial version
+    VERSION = '1.0'
+
+    fields = {
+        'identifier': fields.Field(fields.Integer(), default=123)
+    }
+
+
 class TestObjectVersionChecker(test.TestCase):
     def setUp(self):
         super(TestObjectVersionChecker, self).setUp()
@@ -344,7 +354,8 @@ class TestObjectVersionChecker(test.TestCase):
         with mock.patch.object(self.ovc, '_test_object_compatibility') as toc:
             self.ovc.test_compatibility_routines()
 
-        toc.assert_called_once_with(MyObject, manifest=None)
+        toc.assert_called_once_with(MyObject, manifest=None, init_args=[],
+                                    init_kwargs={})
 
     def test_test_compatibility_routines_with_manifest(self):
         # Make sure test_compatibility_routines() uses the version manifest
@@ -358,7 +369,21 @@ class TestObjectVersionChecker(test.TestCase):
                 self.ovc.test_compatibility_routines(use_manifest=True)
 
         otgv.assert_called_once_with(MyObject.__name__)
-        toc.assert_called_once_with(MyObject, manifest=man)
+        toc.assert_called_once_with(MyObject, manifest=man, init_args=[],
+                                    init_kwargs={})
+
+    def test_test_compatibility_routines_with_args_kwargs(self):
+        # Make sure test_compatibility_routines() uses init args/kwargs
+        del self.ovc.obj_classes[MyObject2.__name__]
+        init_args = {MyObject: [1]}
+        init_kwargs = {MyObject: {'foo': 'bar'}}
+
+        with mock.patch.object(self.ovc, '_test_object_compatibility') as toc:
+            self.ovc.test_compatibility_routines(init_args=init_args,
+                                                 init_kwargs=init_kwargs)
+
+        toc.assert_called_once_with(MyObject, manifest=None, init_args=[1],
+                                    init_kwargs={'foo': 'bar'})
 
     def test_test_relationships_in_order(self):
         # Make sure test_relationships_in_order() tests the relationships
@@ -537,6 +562,32 @@ class TestObjectVersionChecker(test.TestCase):
                          "_test_object_compatibility() did not test "
                          "obj_to_primitive() on the correct target versions")
 
+    def test_test_object_compatibility_args_kwargs(self):
+        # Make sure _test_object_compatibility() tests obj_to_primitive()
+        # with the correct args and kwargs to init
+        to_prim = mock.MagicMock(spec=callable)
+        MyObject.obj_to_primitive = to_prim
+        MyObject.VERSION = '1.1'
+        args = [1]
+        kwargs = {'foo': 'bar'}
+
+        with mock.patch.object(MyObject, '__init__',
+                               return_value=None) as mock_init:
+            self.ovc._test_object_compatibility(MyObject, init_args=args,
+                                                init_kwargs=kwargs)
+
+        expected_init = ((1,), {'foo': 'bar'})
+        expected_init_calls = [expected_init, expected_init]
+        self.assertEqual(expected_init_calls, mock_init.call_args_list,
+                         "_test_object_compatibility() did not call "
+                         "__init__() properly on the object")
+
+        expected_to_prim = [((), {'target_version': '1.0'}),
+                            ((), {'target_version': '1.1'})]
+        self.assertEqual(expected_to_prim, to_prim.call_args_list,
+                         "_test_object_compatibility() did not test "
+                         "obj_to_primitive() on the correct target versions")
+
     def _add_class(self, obj_classes, cls):
         obj_classes[cls.__name__] = [cls]
 
@@ -551,3 +602,50 @@ class TestObjectVersionChecker(test.TestCase):
         deps = tree.get(parent_cls.__name__, {})
         deps[child_cls.__name__] = '1.0'
         tree[parent_cls.__name__] = deps
+
+
+class TestVersionedObjectRegistryFixture(test.TestCase):
+
+    primitive = {'versioned_object.name': 'FakeResource',
+                 'versioned_object.namespace': 'versionedobjects',
+                 'versioned_object.version': '1.0',
+                 'versioned_object.data': {'identifier': 123}}
+
+    def test_object_registered_temporarily(self):
+        # Test object that has not been registered
+        self.assertRaises(
+            exception.UnsupportedObjectError,
+            FakeResource.obj_from_primitive,
+            self.primitive)
+
+        with fixture.VersionedObjectRegistryFixture() as obj_registry:
+            # Register object locally
+            obj_registry.setUp()
+            obj_registry.register(FakeResource)
+
+            # Test object has now been registered
+            obj = FakeResource.obj_from_primitive(
+                self.primitive)
+            self.assertEqual(obj.identifier, 123)
+            self.assertEqual('1.0', obj.VERSION)
+
+        # Test object that is no longer registered
+        self.assertRaises(
+            exception.UnsupportedObjectError,
+            FakeResource.obj_from_primitive,
+            self.primitive)
+
+
+class TestStableObjectJsonFixture(test.TestCase):
+    def test_changes_sort(self):
+        class TestObject(base.VersionedObject):
+            def obj_what_changed(self):
+                return ['z', 'a']
+
+        obj = TestObject()
+        self.assertEqual(['z', 'a'],
+                         obj.obj_to_primitive()['versioned_object.changes'])
+        with fixture.StableObjectJsonFixture():
+            self.assertEqual(
+                ['a', 'z'],
+                obj.obj_to_primitive()['versioned_object.changes'])
