@@ -289,21 +289,40 @@ class TestRegistry(test.TestCase):
             mock_hook.assert_called_once_with(TestObjectNewer, 0)
 
     def test_subclassability(self):
-        class MyRegistry(base.VersionedObjectRegistry):
-            pass
+        class MyRegistryOne(base.VersionedObjectRegistry):
 
-        @MyRegistry.register
-        class ObjectInSubclassedRegistry(object):
-            fields = {}
+            def registration_hook(self, cls, index):
+                cls.reg_to = "one"
 
-            @classmethod
-            def obj_name(cls):
-                return cls.__name__
+        class MyRegistryTwo(base.VersionedObjectRegistry):
 
-        self.assertIn('ObjectInSubclassedRegistry',
-                      MyRegistry.obj_classes())
-        self.assertIn('ObjectInSubclassedRegistry',
+            def registration_hook(self, cls, index):
+                cls.reg_to = "two"
+
+        @MyRegistryOne.register
+        class AVersionedObject1(base.VersionedObject):
+            VERSION = '1.0'
+            fields = {'baz': fields.Field(fields.Integer())}
+
+        @MyRegistryTwo.register
+        class AVersionedObject2(base.VersionedObject):
+            VERSION = '1.0'
+            fields = {'baz': fields.Field(fields.Integer())}
+
+        self.assertIn('AVersionedObject1',
+                      MyRegistryOne.obj_classes())
+        self.assertIn('AVersionedObject2',
+                      MyRegistryOne.obj_classes())
+        self.assertIn('AVersionedObject1',
+                      MyRegistryTwo.obj_classes())
+        self.assertIn('AVersionedObject2',
+                      MyRegistryTwo.obj_classes())
+        self.assertIn('AVersionedObject1',
                       base.VersionedObjectRegistry.obj_classes())
+        self.assertIn('AVersionedObject2',
+                      base.VersionedObjectRegistry.obj_classes())
+        self.assertEqual(AVersionedObject1.reg_to, "one")
+        self.assertEqual(AVersionedObject2.reg_to, "two")
 
 
 class TestObjMakeList(test.TestCase):
@@ -596,10 +615,14 @@ class TestFixture(_BaseTestCase):
         def test(mock_compat):
             checker.test_compatibility_routines()
             mock_compat.assert_has_calls(
-                [mock.call(mock.sentinel.impl_one_one, manifest=None),
-                 mock.call(mock.sentinel.impl_one_two, manifest=None),
-                 mock.call(mock.sentinel.impl_two_one, manifest=None),
-                 mock.call(mock.sentinel.impl_two_two, manifest=None)],
+                [mock.call(mock.sentinel.impl_one_one, manifest=None,
+                           init_args=[], init_kwargs={}),
+                 mock.call(mock.sentinel.impl_one_two, manifest=None,
+                           init_args=[], init_kwargs={}),
+                 mock.call(mock.sentinel.impl_two_one, manifest=None,
+                           init_args=[], init_kwargs={}),
+                 mock.call(mock.sentinel.impl_two_two, manifest=None,
+                           init_args=[], init_kwargs={})],
                 any_order=True)
         test()
 
@@ -1060,6 +1083,21 @@ class _TestObject(object):
         obj = TestObj()
         self.assertEqual(['foo', 'bar'], obj.obj_fields)
 
+    def test_obj_context(self):
+        class TestObj(base.VersionedObject):
+            pass
+
+        # context is available through the public property
+        context = mock.Mock()
+        obj = TestObj(context)
+        self.assertEqual(context, obj.obj_context)
+
+        # ..but it's not available for update
+        new_context = mock.Mock()
+        self.assertRaises(
+            AttributeError,
+            setattr, obj, 'obj_context', new_context)
+
     def test_obj_constructor(self):
         obj = MyObj(context=self.context, foo=123, bar='abc')
         self.assertEqual(123, obj.foo)
